@@ -770,7 +770,9 @@ class CmdExecute(object):
                         if nPos == (len(statementLines) - 1):
                             # 都已经到最后一行了，不需要继续等待了
                             statementFinished = True
-                        if currentStatement.strip().endswith(';') and not missedSQLSlash:
+                        if not currentStatement.strip().startswith("_") and \
+                                currentStatement.strip().endswith(';') and \
+                                not missedSQLSlash:
                             # 遇到了分号，且不是复合语句，那么直接结束
                             statementFinished = True
                         if currentStatement.strip().endswith("\n/"):
@@ -793,6 +795,10 @@ class CmdExecute(object):
                                 currentStatement = None
                                 currentStatementWithComments = None
                             else:
+                                if currentStatement.strip().endswith("\n/"):
+                                    currentStatement = currentStatement[:-2]
+                                elif currentStatement.strip().endswith(";"):
+                                    currentStatement = currentStatement[:-1]
                                 ret_CommandSplitResults.append(
                                     {'name': 'SQL_UNKNOWN',
                                      'statement': currentStatement,
@@ -1466,7 +1472,9 @@ class CmdExecute(object):
                     yield result
             elif parseObject["name"] in ["COMPARE"]:
                 for result in executeCompareRequest(
+                        cls=self.cliHandler,
                         requestObject=parseObject,
+                        commandScriptFile=commandScriptFile
                 ):
                     yield result
             elif parseObject["name"] in ["DATA"]:
