@@ -12,7 +12,6 @@ from ..sqlclijdbc import connect as jdbcconnect
 from ..test.testmockserver import startServer
 from ..test.testmockserver import stopServer
 from ..test.testmockserver import waitServerRunning
-from ..testcli import TestCli
 
 
 class TestSynatx(unittest.TestCase):
@@ -33,127 +32,155 @@ class TestSynatx(unittest.TestCase):
         self.assertEqual(0, ret_errorCode)
         self.assertEqual(None, ret_errorMsg)
 
-    def test_SQLAnalyze_ConnectH2Mem(self):
-        # connect with local h2 mem
-        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
-            = SQLAnalyze("_connect /mem")
-        self.assertTrue(isFinished)
-        self.assertEqual({'localService': 'mem', 'name': 'CONNECT'}, ret_CommandSplitResult)
-        self.assertEqual(0, ret_errorCode)
-        self.assertEqual(None, ret_errorMsg)
+    def test_SQLAnalyze_Connect(self):
+        # # connect with local h2 mem
+        # (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+        #     = SQLAnalyze("_connect SYSDBA/Dameng123:62310jdbc:dm://10.15.1.19:6231/")
+        # self.assertTrue(isFinished)
+        # self.assertEqual({'name': 'CONNECT', 'password': 'Dameng123', 'username': 'SYSDBA'}, ret_CommandSplitResult)
+        # self.assertEqual(1, ret_errorCode)
+        # self.assertEqual("line1:25  mismatched input ':62310' expecting <EOF> ", ret_errorMsg)
+        #
+        # # connect with local h2 mem
+        # (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+        #     = SQLAnalyze("_connect /mem")
+        # self.assertTrue(isFinished)
+        # self.assertEqual({'localService': 'mem', 'name': 'CONNECT'}, ret_CommandSplitResult)
+        # self.assertEqual(0, ret_errorCode)
+        # self.assertEqual(None, ret_errorMsg)
+        #
+        # # Connect with testcli metadata
+        # (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+        #     = SQLAnalyze("_connect /metadata")
+        # self.assertTrue(isFinished)
+        # self.assertEqual({'localService': 'metadata', 'name': 'CONNECT'}, ret_CommandSplitResult)
+        # self.assertEqual(0, ret_errorCode)
+        # self.assertEqual(None, ret_errorMsg)
+        #
+        # # connect without server url
+        # (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+        #     = SQLAnalyze("_connect admin/123456")
+        # self.assertTrue(isFinished)
+        # self.assertEqual({'name': 'CONNECT',
+        #                   'password': '123456',
+        #                   'username': 'admin'
+        #                   }, ret_CommandSplitResult)
+        # self.assertEqual(0, ret_errorCode)
+        # self.assertEqual(None, ret_errorMsg)
+        #
+        # # Connect with Oracle8
+        # (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+        #     = SQLAnalyze("_connect \"工具人1号\"/123456@jdbc:oracle:thin://192.168.1.72:1521:xe")
+        # self.assertTrue(isFinished)
+        # self.assertEqual({'driver': 'jdbc',
+        #                   'driverSchema': 'oracle',
+        #                   'driverType': 'thin',
+        #                   'host': '192.168.1.72',
+        #                   'name': 'CONNECT',
+        #                   'password': '123456',
+        #                   'port': 1521,
+        #                   'username': '"工具人1号"',
+        #                   'service': 'xe'
+        #                   }, ret_CommandSplitResult)
+        # self.assertEqual(0, ret_errorCode)
+        # self.assertEqual(None, ret_errorMsg)
+        #
+        # # Connect with Oracle11
+        # (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+        #     = SQLAnalyze("_connect system/123456@jdbc:oracle:thin://192.168.1.72:1521/xe")
+        # self.assertTrue(isFinished)
+        # self.assertEqual({'driver': 'jdbc',
+        #                   'driverSchema': 'oracle',
+        #                   'driverType': 'thin',
+        #                   'host': '192.168.1.72',
+        #                   'name': 'CONNECT',
+        #                   'password': '123456',
+        #                   'port': 1521,
+        #                   'service': 'xe',
+        #                   'username': 'system'}, ret_CommandSplitResult)
+        # self.assertEqual(0, ret_errorCode)
+        # self.assertEqual(None, ret_errorMsg)
+        #
+        # # connect with teradata
+        # # teradata与众不同，其没有serviceName的存在
+        # (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+        #     = SQLAnalyze("_connect testdblink/testdblink@jdbc:teradata://192.168.1.136/testbase")
+        # self.assertTrue(isFinished)
+        # self.assertEqual({'driver': 'jdbc',
+        #                   'driverSchema': 'teradata',
+        #                   'host': '192.168.1.136',
+        #                   'name': 'CONNECT',
+        #                   'password': 'testdblink',
+        #                   'service': 'testbase',
+        #                   'username': 'testdblink'}, ret_CommandSplitResult)
+        # self.assertEqual(0, ret_errorCode)
+        # self.assertEqual(None, ret_errorMsg)
+        #
+        # # Connect with named h2 session
+        # (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+        #     = SQLAnalyze("_connect sa/sa@jdbc:h2tcp:tcp://127.0.0.1:19091/mem:test")
+        # self.assertTrue(isFinished)
+        # self.assertEqual({'driver': 'jdbc',
+        #                   'driverSchema': 'h2tcp',
+        #                   'driverType': 'tcp',
+        #                   'host': '127.0.0.1',
+        #                   'name': 'CONNECT',
+        #                   'password': 'sa',
+        #                   'port': 19091,
+        #                   'service': 'mem:test',
+        #                   'username': 'sa'}, ret_CommandSplitResult)
+        # self.assertEqual(0, ret_errorCode)
+        # self.assertEqual(None, ret_errorMsg)
+        #
+        # # Connect with IPV6
+        # (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+        #     = SQLAnalyze("_connect sa/sa@jdbc:h2tcp:tcp://[0:0:0:0:0:ffff:192.1.56.10]:19091/mem:test")
+        # self.assertTrue(isFinished)
+        # self.assertEqual({'driver': 'jdbc',
+        #                   'driverSchema': 'h2tcp',
+        #                   'driverType': 'tcp',
+        #                   'host': '[0:0:0:0:0:ffff:192.1.56.10]',
+        #                   'name': 'CONNECT',
+        #                   'password': 'sa',
+        #                   'port': 19091,
+        #                   'service': 'mem:test',
+        #                   'username': 'sa'}, ret_CommandSplitResult)
+        # self.assertEqual(0, ret_errorCode)
+        # self.assertEqual(None, ret_errorMsg)
+        #
+        # # Connect with IPV6
+        # (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+        #     = SQLAnalyze("_connect sa/sa@jdbc:h2tcp:tcp://[FE80::5689:98FF:FE14]:19091/mem:test")
+        # self.assertTrue(isFinished)
+        # self.assertEqual({'driver': 'jdbc',
+        #                   'driverSchema': 'h2tcp',
+        #                   'driverType': 'tcp',
+        #                   'host': '[FE80::5689:98FF:FE14]',
+        #                   'name': 'CONNECT',
+        #                   'password': 'sa',
+        #                   'port': 19091,
+        #                   'service': 'mem:test',
+        #                   'username': 'sa'}, ret_CommandSplitResult)
+        # self.assertEqual(0, ret_errorCode)
+        # self.assertEqual(None, ret_errorMsg)
 
-        # Connect with testcli metadata
         (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
-            = SQLAnalyze("_connect /metadata")
+            = SQLAnalyze("_connect aa/bb@jdbc:dm://10.10.10.10:6231?autocommit=false&dd=yy")
         self.assertTrue(isFinished)
-        self.assertEqual({'localService': 'metadata', 'name': 'CONNECT'}, ret_CommandSplitResult)
-        self.assertEqual(0, ret_errorCode)
-        self.assertEqual(None, ret_errorMsg)
-
-        # connect without server url
-        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
-            = SQLAnalyze("_connect admin/123456")
-        self.assertTrue(isFinished)
-        self.assertEqual({'name': 'CONNECT',
-                          'password': '123456',
-                          'username': 'admin'
-                          }, ret_CommandSplitResult)
-        self.assertEqual(0, ret_errorCode)
-        self.assertEqual(None, ret_errorMsg)
-
-        # Connect with Oracle8
-        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
-            = SQLAnalyze("_connect \"工具人1号\"/123456@jdbc:oracle:thin://192.168.1.72:1521:xe")
-        self.assertTrue(isFinished)
-        self.assertEqual({'driver': 'jdbc',
-                          'driverSchema': 'oracle',
-                          'driverType': 'thin',
-                          'host': '192.168.1.72',
-                          'name': 'CONNECT',
-                          'password': '123456',
-                          'port': 1521,
-                          'username': '"工具人1号"',
-                          'service': 'xe'
-                          }, ret_CommandSplitResult)
-        self.assertEqual(0, ret_errorCode)
-        self.assertEqual(None, ret_errorMsg)
-
-        # Connect with Oracle11
-        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
-            = SQLAnalyze("_connect system/123456@jdbc:oracle:thin://192.168.1.72:1521/xe")
-        self.assertTrue(isFinished)
-        self.assertEqual({'driver': 'jdbc',
-                          'driverSchema': 'oracle',
-                          'driverType': 'thin',
-                          'host': '192.168.1.72',
-                          'name': 'CONNECT',
-                          'password': '123456',
-                          'port': 1521,
-                          'service': 'xe',
-                          'username': 'system'}, ret_CommandSplitResult)
-        self.assertEqual(0, ret_errorCode)
-        self.assertEqual(None, ret_errorMsg)
-
-        # connect with teradata
-        # teradata与众不同，其没有serviceName的存在
-        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
-            = SQLAnalyze("_connect testdblink/testdblink@jdbc:teradata://192.168.1.136/testbase")
-        self.assertTrue(isFinished)
-        self.assertEqual({'driver': 'jdbc',
-                          'driverSchema': 'teradata',
-                          'host': '192.168.1.136',
-                          'name': 'CONNECT',
-                          'password': 'testdblink',
-                          'service': 'testbase',
-                          'username': 'testdblink'}, ret_CommandSplitResult)
-        self.assertEqual(0, ret_errorCode)
-        self.assertEqual(None, ret_errorMsg)
-
-        # Connect with named h2 session
-        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
-            = SQLAnalyze("_connect sa/sa@jdbc:h2tcp:tcp://127.0.0.1:19091/mem:test")
-        self.assertTrue(isFinished)
-        self.assertEqual({'driver': 'jdbc',
-                          'driverSchema': 'h2tcp',
-                          'driverType': 'tcp',
-                          'host': '127.0.0.1',
-                          'name': 'CONNECT',
-                          'password': 'sa',
-                          'port': 19091,
-                          'service': 'mem:test',
-                          'username': 'sa'}, ret_CommandSplitResult)
-        self.assertEqual(0, ret_errorCode)
-        self.assertEqual(None, ret_errorMsg)
-
-        # Connect with IPV6
-        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
-            = SQLAnalyze("_connect sa/sa@jdbc:h2tcp:tcp://[0:0:0:0:0:ffff:192.1.56.10]:19091/mem:test")
-        self.assertTrue(isFinished)
-        self.assertEqual({'driver': 'jdbc',
-                          'driverSchema': 'h2tcp',
-                          'driverType': 'tcp',
-                          'host': '[0:0:0:0:0:ffff:192.1.56.10]',
-                          'name': 'CONNECT',
-                          'password': 'sa',
-                          'port': 19091,
-                          'service': 'mem:test',
-                          'username': 'sa'}, ret_CommandSplitResult)
-        self.assertEqual(0, ret_errorCode)
-        self.assertEqual(None, ret_errorMsg)
-
-        # Connect with IPV6
-        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
-            = SQLAnalyze("_connect sa/sa@jdbc:h2tcp:tcp://[FE80::5689:98FF:FE14]:19091/mem:test")
-        self.assertTrue(isFinished)
-        self.assertEqual({'driver': 'jdbc',
-                          'driverSchema': 'h2tcp',
-                          'driverType': 'tcp',
-                          'host': '[FE80::5689:98FF:FE14]',
-                          'name': 'CONNECT',
-                          'password': 'sa',
-                          'port': 19091,
-                          'service': 'mem:test',
-                          'username': 'sa'}, ret_CommandSplitResult)
+        self.assertEqual(
+            {
+                'driver': 'jdbc',
+                'driverSchema': 'dm',
+                'host': '10.10.10.10',
+                'name': 'CONNECT',
+                'parameters': [
+                    {'parameterName': 'autocommit', 'parameterValue': 'false'},
+                    {'parameterName': 'dd', 'parameterValue': 'yy'}
+                ],
+                'password': 'bb',
+                'port': 6231,
+                'username': 'aa'
+            }, ret_CommandSplitResult)
         self.assertEqual(0, ret_errorCode)
         self.assertEqual(None, ret_errorMsg)
 
@@ -247,7 +274,13 @@ class TestSynatx(unittest.TestCase):
         (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
             = SQLAnalyze("_Assert {% assert expresssion %}")
         self.assertTrue(isFinished)
-        self.assertEqual({'assertName': None, 'name': 'ASSERT', 'expression': ' assert expresssion '}, ret_CommandSplitResult)
+        self.assertEqual(
+            {
+                'assertName': None,
+                'name': 'ASSERT',
+                'expression': ' assert expresssion '
+            },
+            ret_CommandSplitResult)
         self.assertEqual(None, ret_errorMsg)
         self.assertEqual(0, ret_errorCode)
 
@@ -255,7 +288,7 @@ class TestSynatx(unittest.TestCase):
         (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
             = SQLAnalyze("_set")
         self.assertTrue(isFinished)
-        self.assertEqual({'name': 'SET', 'scope': 'local'}, ret_CommandSplitResult)
+        self.assertEqual({'name': 'SET'}, ret_CommandSplitResult)
         self.assertEqual(0, ret_errorCode)
         self.assertEqual(None, ret_errorMsg)
 
@@ -264,8 +297,7 @@ class TestSynatx(unittest.TestCase):
             = SQLAnalyze("_set @aa bbb")
         self.assertTrue(isFinished)
         self.assertEqual({'name': 'SET',
-                          'scope': 'global',
-                          'optionName': 'aa',
+                          'optionName': '@aa',
                           'optionValue': 'bbb'}, ret_CommandSplitResult)
         self.assertEqual(0, ret_errorCode)
         self.assertEqual(None, ret_errorMsg)
@@ -276,8 +308,7 @@ class TestSynatx(unittest.TestCase):
         self.assertTrue(isFinished)
         self.assertEqual({'name': 'SET',
                           'optionName': 'XX',
-                          'optionValue': 'YY',
-                          'scope': 'local'}, ret_CommandSplitResult)
+                          'optionValue': 'YY'}, ret_CommandSplitResult)
         self.assertEqual(0, ret_errorCode)
         self.assertEqual(None, ret_errorMsg)
 
@@ -287,8 +318,7 @@ class TestSynatx(unittest.TestCase):
         self.assertTrue(isFinished)
         self.assertEqual({'name': 'SET',
                           'optionName': 'ZZ',
-                          'optionValue': 'DD FF',
-                          'scope': 'local'
+                          'optionValue': 'DD FF'
                           }, ret_CommandSplitResult)
         self.assertEqual(0, ret_errorCode)
         self.assertEqual(None, ret_errorMsg)
@@ -301,21 +331,6 @@ class TestSynatx(unittest.TestCase):
         self.assertEqual(0, ret_errorCode)
         self.assertEqual(None, ret_errorMsg)
 
-    def test_SQLAnalyze_CommitAndRollback(self):
-        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
-            = SQLAnalyze("commit")
-        self.assertTrue(isFinished)
-        self.assertEqual({'name': 'COMMIT', 'statement': 'commit'}, ret_CommandSplitResult)
-        self.assertEqual(0, ret_errorCode)
-        self.assertEqual(None, ret_errorMsg)
-
-        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
-            = SQLAnalyze("rollback")
-        self.assertTrue(isFinished)
-        self.assertEqual({'name': 'ROLLBACK', 'statement': 'rollback'}, ret_CommandSplitResult)
-        self.assertEqual(0, ret_errorCode)
-        self.assertEqual(None, ret_errorMsg)
-
     def test_SQLAnalyze_Echo(self):
         strEchoContent = "aaa" + "\n" + \
                          "bbb" + "\n" + \
@@ -699,6 +714,69 @@ class TestSynatx(unittest.TestCase):
              'user': 'root'},
             ret_CommandSplitResult)
 
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+            = SQLAnalyze(
+            """
+                _ssh execute  "source ~/.bash_profile;cli  << EOF
+                restore database 'xxdb1'  from backupset 'set02';
+                exit;
+                EOF
+                "
+            """)
+        self.assertEqual(None, ret_errorMsg)
+        self.assertEqual(0, ret_errorCode)
+        self.assertTrue(isFinished)
+        self.assertEqual(
+            {
+                'action': 'execute',
+                'command': 'source ~/.bash_profile;cli  << EOF\n'
+                           "                restore database 'xxdb1'  from backupset "
+                           "'set02';\n"
+                           '                exit;\n'
+                           '                EOF\n'
+                           '                ',
+                'name': 'SSH'},
+            ret_CommandSplitResult)
+
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+            = SQLAnalyze(
+            """
+                _ssh execute  "source ~/.bash_profile;cli << EOF
+                restore database 'xxdb'  from backupset 'set01' IDENTIFIED BY "pass1";
+                exit;
+                EOF";
+            """)
+        self.assertEqual(None, ret_errorMsg)
+        self.assertEqual(0, ret_errorCode)
+        self.assertTrue(isFinished)
+        self.assertEqual(
+            {
+                'action': 'execute',
+                'command': 'source ~/.bash_profile;cli << EOF\n'
+                           "                restore database 'xxdb'  from backupset 'set01' "
+                           'IDENTIFIED BY "pass1";\n'
+                           '                exit;\n'
+                           '                EOF',
+                'name': 'SSH'},
+            ret_CommandSplitResult)
+
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+            = SQLAnalyze(
+            """
+                _ssh execute  "source ~/.bash_profile;cli << EOF
+                restore database 'xxdb'  from backupset 'set01' IDENTIFIED BY "pass1";
+            """)
+        self.assertTrue(ret_errorMsg.startswith("Missing <EOF> un-closed qutote string."))
+        self.assertEqual(1, ret_errorCode)
+        self.assertFalse(isFinished)
+        self.assertEqual(
+            {
+                'action': 'execute',
+                'command': '',
+                'name': 'SSH'
+            },
+            ret_CommandSplitResult)
+
     def test_SQLAnalyze_Job(self):
         (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
             = SQLAnalyze("_JOB JOBMANAGER ON")
@@ -959,7 +1037,7 @@ class TestSynatx(unittest.TestCase):
             ret_CommandSplitResult)
 
         (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
-            = SQLAnalyze("_DATA CONVERT FS FILE aa.txt FROM MEM FILE bb.dat")
+            = SQLAnalyze("_DATA CONVERT FS FILE aa.txt TO MEM FILE bb.dat")
         self.assertEqual(None, ret_errorMsg)
         self.assertEqual(0, ret_errorCode)
         self.assertTrue(isFinished)
@@ -977,10 +1055,10 @@ class TestSynatx(unittest.TestCase):
         (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
             = SQLAnalyze(
             "_DATA CREATE FS FILE aa.txt \n" +
-            "[\n" +
+            "(\n" +
             "random_int(10), 'aaa'\n" +
             "bb, ccd"
-            + "] rows 1000"
+            + ") rows 1000;"
         )
         self.assertEqual(None, ret_errorMsg)
         self.assertEqual(0, ret_errorCode)
@@ -988,7 +1066,7 @@ class TestSynatx(unittest.TestCase):
         self.assertEqual(
             {
                 'action': 'create',
-                'columnExpression': "random_int(10),'aaa'bb,ccd",
+                'columnExpression': "random_int(10), 'aaa'\nbb, ccd",
                 'fileType': 'FS',
                 'name': 'DATA',
                 'rowCount': 1000,
@@ -996,7 +1074,111 @@ class TestSynatx(unittest.TestCase):
              },
             ret_CommandSplitResult)
 
+    def test_SQLAnalyze_Monitor(self):
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) = SQLAnalyze("_MONITOR MONITORMANAGER ON")
+        self.assertEqual(None, ret_errorMsg)
+        self.assertEqual(0, ret_errorCode)
+        self.assertTrue(isFinished)
+        self.assertEqual(
+            {
+                'action': 'startManager',
+                'name': 'MONITOR',
+                'workerThreads': None
+            },
+            ret_CommandSplitResult)
+
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) = \
+            SQLAnalyze("_MONITOR MONITORMANAGER ON WORKERS 5")
+        self.assertEqual(None, ret_errorMsg)
+        self.assertEqual(0, ret_errorCode)
+        self.assertTrue(isFinished)
+        self.assertEqual(
+            {
+                'action': 'startManager',
+                'name': 'MONITOR',
+                'workerThreads': 5,
+            },
+            ret_CommandSplitResult)
+
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) = SQLAnalyze("_MONITOR MONITORMANAGER OFF")
+        self.assertEqual(None, ret_errorMsg)
+        self.assertEqual(0, ret_errorCode)
+        self.assertTrue(isFinished)
+        self.assertEqual(
+            {
+                'action': 'stopManager',
+                'name': 'MONITOR',
+            },
+            ret_CommandSplitResult)
+
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) = \
+            SQLAnalyze("_MONITOR START TASK task1")
+        self.assertEqual(None, ret_errorMsg)
+        self.assertEqual(0, ret_errorCode)
+        self.assertTrue(isFinished)
+        self.assertEqual(
+            {
+                'action': 'startTask',
+                'name': 'MONITOR',
+                'taskName': 'task1'
+            },
+            ret_CommandSplitResult)
+
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) = \
+            SQLAnalyze("_MONITOR REPORT TASK task1")
+        self.assertEqual(None, ret_errorMsg)
+        self.assertEqual(0, ret_errorCode)
+        self.assertTrue(isFinished)
+        self.assertEqual(
+            {
+                'action': 'reportTask',
+                'name': 'MONITOR',
+                'taskName': 'task1'
+            },
+            ret_CommandSplitResult)
+
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) = \
+            SQLAnalyze("_MONITOR STOP TASK task1")
+        self.assertEqual(None, ret_errorMsg)
+        self.assertEqual(0, ret_errorCode)
+        self.assertTrue(isFinished)
+        self.assertEqual(
+            {
+                'action': 'stopTask',
+                'name': 'MONITOR',
+                'taskName': 'task1'
+            },
+            ret_CommandSplitResult)
+
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) = \
+            SQLAnalyze("_MONITOR CREATE TASK task1 UID=aaa PWD=YYY")
+        self.assertEqual(None, ret_errorMsg)
+        self.assertEqual(0, ret_errorCode)
+        self.assertTrue(isFinished)
+        self.assertEqual(
+            {
+                'action': 'createTask',
+                'name': 'MONITOR',
+                'param': {'PWD': 'YYY', 'UID': 'aaa'},
+                'taskName': 'task1'
+             },
+            ret_CommandSplitResult)
+
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) = \
+            SQLAnalyze("_MONITOR LIST TASK")
+        self.assertEqual(None, ret_errorMsg)
+        self.assertEqual(0, ret_errorCode)
+        self.assertTrue(isFinished)
+        self.assertEqual(
+            {
+                'action': 'listTask',
+                'name': 'MONITOR'
+            },
+            ret_CommandSplitResult)
+
     def test_SQLExecuteSanity(self):
+        from ..testcli import TestCli
+
         scriptFile = "testsqlsanity.sql"
 
         scriptBaseFile = os.path.splitext(scriptFile)[0]
@@ -1004,7 +1186,7 @@ class TestSynatx(unittest.TestCase):
         fullRefFile = os.path.abspath(os.path.join(os.path.dirname(__file__), "", scriptBaseFile + ".ref"))
         fullLogFile = os.path.abspath(os.path.join(tempfile.gettempdir(), scriptBaseFile + ".log"))
 
-        # 运行测试程序，开启无头模式(不再控制台上显示任何内容),同时不打印Logo
+        # 运行测试程序，开启无头模式(不在控制台上显示任何内容),同时不打印Logo
         testcli = TestCli(
             logfilename=fullLogFile,
             headlessMode=True,
@@ -1028,6 +1210,8 @@ class TestSynatx(unittest.TestCase):
         self.assertTrue(compareResult)
 
     def test_SQLExecuteWithStartParameter(self):
+        from ..testcli import TestCli
+
         scriptFile = "testsqlstart.sql"
 
         scriptBaseFile = os.path.splitext(scriptFile)[0]
@@ -1035,7 +1219,7 @@ class TestSynatx(unittest.TestCase):
         fullRefFile = os.path.abspath(os.path.join(os.path.dirname(__file__), "", scriptBaseFile + ".ref"))
         fullLogFile = os.path.abspath(os.path.join(tempfile.gettempdir(), scriptBaseFile + ".log"))
 
-        # 运行测试程序，开启无头模式(不再控制台上显示任何内容),同时不打印Logo
+        # 运行测试程序，开启无头模式(不在控制台上显示任何内容),同时不打印Logo
         testcli = TestCli(
             logfilename=fullLogFile,
             headlessMode=True,
@@ -1059,6 +1243,8 @@ class TestSynatx(unittest.TestCase):
         self.assertTrue(compareResult)
 
     def test_SQLExecuteWithSQLCLI_CONNECTION_URL(self):
+        from ..testcli import TestCli
+
         h2JarFile = os.path.abspath(os.path.join(os.path.dirname(__file__), "..", "jlib", "h2-1.4.200.jar"))
         jarList = [h2JarFile, ]
         jdbcconnect(jclassname="org.h2.Driver",
@@ -1068,6 +1254,7 @@ class TestSynatx(unittest.TestCase):
         tcpServer = jpype.JClass("org.h2.tools.Server").\
             createTcpServer("-tcp", "-tcpAllowOthers", "-tcpPort", str(19091))
         tcpServer.start()
+        time.sleep(2)
         os.environ["SQLCLI_CONNECTION_URL"] = "jdbc:h2tcp:tcp://127.0.0.1:19091/mem:test"
 
         scriptFile = "testsqlwithurl.sql"
@@ -1076,7 +1263,7 @@ class TestSynatx(unittest.TestCase):
         fullRefFile = os.path.abspath(os.path.join(os.path.dirname(__file__), "", scriptBaseFile + ".ref"))
         fullLogFile = os.path.abspath(os.path.join(tempfile.gettempdir(), scriptBaseFile + ".log"))
 
-        # 运行测试程序，开启无头模式(不再控制台上显示任何内容),同时不打印Logo
+        # 运行测试程序，开启无头模式(不在控制台上显示任何内容),同时不打印Logo
         testcli = TestCli(
             logfilename=fullLogFile,
             headlessMode=True,
@@ -1102,6 +1289,8 @@ class TestSynatx(unittest.TestCase):
         self.assertTrue(compareResult)
 
     def test_SQLSleep(self):
+        from ..testcli import TestCli
+
         # 记录开始时间
         start = time.time()
 
@@ -1112,7 +1301,7 @@ class TestSynatx(unittest.TestCase):
         fullRefFile = os.path.abspath(os.path.join(os.path.dirname(__file__), "", scriptBaseFile + ".ref"))
         fullLogFile = os.path.abspath(os.path.join(tempfile.gettempdir(), scriptBaseFile + ".log"))
 
-        # 运行测试程序，开启无头模式(不再控制台上显示任何内容),同时不打印Logo
+        # 运行测试程序，开启无头模式(不在控制台上显示任何内容),同时不打印Logo
         testcli = TestCli(
             logfilename=fullLogFile,
             headlessMode=True,
@@ -1139,6 +1328,8 @@ class TestSynatx(unittest.TestCase):
         self.assertTrue(compareResult)
 
     def test_SQLEmbeddScript(self):
+        from ..testcli import TestCli
+
         scriptFile = "testsqlembeddscript.sql"
 
         scriptBaseFile = os.path.splitext(scriptFile)[0]
@@ -1146,7 +1337,7 @@ class TestSynatx(unittest.TestCase):
         fullRefFile = os.path.abspath(os.path.join(os.path.dirname(__file__), "", scriptBaseFile + ".ref"))
         fullLogFile = os.path.abspath(os.path.join(tempfile.gettempdir(), scriptBaseFile + ".log"))
 
-        # 运行测试程序，开启无头模式(不再控制台上显示任何内容),同时不打印Logo
+        # 运行测试程序，开启无头模式(不在控制台上显示任何内容),同时不打印Logo
         testcli = TestCli(
             logfilename=fullLogFile,
             headlessMode=True,
@@ -1169,6 +1360,8 @@ class TestSynatx(unittest.TestCase):
         self.assertTrue(compareResult)
 
     def test_SQLSessionManage(self):
+        from ..testcli import TestCli
+
         scriptFile = "testsessionmanage.sql"
 
         scriptBaseFile = os.path.splitext(scriptFile)[0]
@@ -1176,7 +1369,7 @@ class TestSynatx(unittest.TestCase):
         fullRefFile = os.path.abspath(os.path.join(os.path.dirname(__file__), "", scriptBaseFile + ".ref"))
         fullLogFile = os.path.abspath(os.path.join(tempfile.gettempdir(), scriptBaseFile + ".log"))
 
-        # 运行测试程序，开启无头模式(不再控制台上显示任何内容),同时不打印Logo
+        # 运行测试程序，开启无头模式(不在控制台上显示任何内容),同时不打印Logo
         testcli = TestCli(
             logfilename=fullLogFile,
             headlessMode=True,
@@ -1199,6 +1392,8 @@ class TestSynatx(unittest.TestCase):
         self.assertTrue(compareResult)
 
     def test_SQLIfAndLoopCondition(self):
+        from ..testcli import TestCli
+
         scriptFile = "testsqlifandloop.sql"
 
         scriptBaseFile = os.path.splitext(scriptFile)[0]
@@ -1206,7 +1401,7 @@ class TestSynatx(unittest.TestCase):
         fullRefFile = os.path.abspath(os.path.join(os.path.dirname(__file__), "", scriptBaseFile + ".ref"))
         fullLogFile = os.path.abspath(os.path.join(tempfile.gettempdir(), scriptBaseFile + ".log"))
 
-        # 运行测试程序，开启无头模式(不再控制台上显示任何内容),同时不打印Logo
+        # 运行测试程序，开启无头模式(不在控制台上显示任何内容),同时不打印Logo
         testcli = TestCli(
             logfilename=fullLogFile,
             headlessMode=True,
@@ -1229,6 +1424,8 @@ class TestSynatx(unittest.TestCase):
         self.assertTrue(compareResult)
 
     def test_SQLLoadPlugin(self):
+        from ..testcli import TestCli
+
         scriptFile = "testplugin.sql"
 
         scriptBaseFile = os.path.splitext(scriptFile)[0]
@@ -1236,7 +1433,7 @@ class TestSynatx(unittest.TestCase):
         fullRefFile = os.path.abspath(os.path.join(os.path.dirname(__file__), "", scriptBaseFile + ".ref"))
         fullLogFile = os.path.abspath(os.path.join(tempfile.gettempdir(), scriptBaseFile + ".log"))
 
-        # 运行测试程序，开启无头模式(不再控制台上显示任何内容),同时不打印Logo
+        # 运行测试程序，开启无头模式(不在控制台上显示任何内容),同时不打印Logo
         testcli = TestCli(
             logfilename=fullLogFile,
             headlessMode=True,
@@ -1259,6 +1456,8 @@ class TestSynatx(unittest.TestCase):
         self.assertTrue(compareResult)
 
     def test_SQLWhenever(self):
+        from ..testcli import TestCli
+
         scriptFile = "testsqlwhenever.sql"
 
         scriptBaseFile = os.path.splitext(scriptFile)[0]
@@ -1266,7 +1465,7 @@ class TestSynatx(unittest.TestCase):
         fullRefFile = os.path.abspath(os.path.join(os.path.dirname(__file__), "", scriptBaseFile + ".ref"))
         fullLogFile = os.path.abspath(os.path.join(tempfile.gettempdir(), scriptBaseFile + ".log"))
 
-        # 运行测试程序，开启无头模式(不再控制台上显示任何内容),同时不打印Logo
+        # 运行测试程序，开启无头模式(不在控制台上显示任何内容),同时不打印Logo
         testcli = TestCli(
             logfilename=fullLogFile,
             headlessMode=True,
@@ -1289,6 +1488,8 @@ class TestSynatx(unittest.TestCase):
         self.assertTrue(compareResult)
 
     def test_SQLJobManager(self):
+        from ..testcli import TestCli
+
         scriptFile = "testjobmanager.sql"
 
         scriptBaseFile = os.path.splitext(scriptFile)[0]
@@ -1296,7 +1497,7 @@ class TestSynatx(unittest.TestCase):
         fullRefFile = os.path.abspath(os.path.join(os.path.dirname(__file__), "", scriptBaseFile + ".ref"))
         fullLogFile = os.path.abspath(os.path.join(tempfile.gettempdir(), scriptBaseFile + ".log"))
 
-        # 运行测试程序，开启无头模式(不再控制台上显示任何内容),同时不打印Logo
+        # 运行测试程序，开启无头模式(不在控制台上显示任何内容),同时不打印Logo
         testcli = TestCli(
             logfilename=fullLogFile,
             headlessMode=True,
@@ -1399,6 +1600,8 @@ class TestSynatx(unittest.TestCase):
         self.assertTrue(compareResult)
 
     def test_APIExecute_Get(self):
+        from ..testcli import TestCli
+
         scriptFile = "testapiget.api"
 
         scriptBaseFile = os.path.splitext(scriptFile)[0]
@@ -1406,7 +1609,7 @@ class TestSynatx(unittest.TestCase):
         fullRefFile = os.path.abspath(os.path.join(os.path.dirname(__file__), "", scriptBaseFile + ".ref"))
         fullLogFile = os.path.abspath(os.path.join(tempfile.gettempdir(), scriptBaseFile + ".log"))
 
-        # 运行测试程序，开启无头模式(不再控制台上显示任何内容),同时不打印Logo
+        # 运行测试程序，开启无头模式(不在控制台上显示任何内容),同时不打印Logo
         testcli = TestCli(
             logfilename=fullLogFile,
             headlessMode=True,
@@ -1430,6 +1633,8 @@ class TestSynatx(unittest.TestCase):
         self.assertTrue(compareResult)
 
     def test_lastcommandresult(self):
+        from ..testcli import TestCli
+
         scriptFile = "testlastcommandresult.sql"
 
         scriptBaseFile = os.path.splitext(scriptFile)[0]
@@ -1437,7 +1642,7 @@ class TestSynatx(unittest.TestCase):
         fullRefFile = os.path.abspath(os.path.join(os.path.dirname(__file__), "", scriptBaseFile + ".ref"))
         fullLogFile = os.path.abspath(os.path.join(tempfile.gettempdir(), scriptBaseFile + ".log"))
 
-        # 运行测试程序，开启无头模式(不再控制台上显示任何内容),同时不打印Logo
+        # 运行测试程序，开启无头模式(不在控制台上显示任何内容),同时不打印Logo
         testcli = TestCli(
             logfilename=fullLogFile,
             headlessMode=True,
@@ -1461,6 +1666,8 @@ class TestSynatx(unittest.TestCase):
         self.assertTrue(compareResult)
 
     def test_compare(self):
+        from ..testcli import TestCli
+
         scriptFile = "testcompare.sql"
 
         scriptBaseFile = os.path.splitext(scriptFile)[0]
@@ -1468,7 +1675,7 @@ class TestSynatx(unittest.TestCase):
         fullRefFile = os.path.abspath(os.path.join(os.path.dirname(__file__), scriptBaseFile + ".ref"))
         fullLogFile = os.path.abspath(os.path.join(tempfile.gettempdir(), scriptBaseFile + ".log"))
 
-        # 运行测试程序，开启无头模式(不再控制台上显示任何内容),同时不打印Logo
+        # 运行测试程序，开启无头模式(不在控制台上显示任何内容),同时不打印Logo
         testcli = TestCli(
             logfilename=fullLogFile,
             headlessMode=True,
@@ -1496,6 +1703,8 @@ class TestSynatx(unittest.TestCase):
         os.remove(fullDiffFile)
 
     def test_sqlmapping(self):
+        from ..testcli import TestCli
+
         scriptFile = "testsqlmapping.sql"
 
         scriptBaseFile = os.path.splitext(scriptFile)[0]
@@ -1503,7 +1712,73 @@ class TestSynatx(unittest.TestCase):
         fullRefFile = os.path.abspath(os.path.join(os.path.dirname(__file__), "", scriptBaseFile + ".ref"))
         fullLogFile = os.path.abspath(os.path.join(tempfile.gettempdir(), scriptBaseFile + ".log"))
 
-        # 运行测试程序，开启无头模式(不再控制台上显示任何内容),同时不打印Logo
+        # 运行测试程序，开启无头模式(不在控制台上显示任何内容),同时不打印Logo
+        testcli = TestCli(
+            logfilename=fullLogFile,
+            headlessMode=True,
+            script=fullScriptFile
+        )
+        retValue = testcli.run_cli()
+        self.assertEqual(0, retValue)
+
+        # 对文件进行比对，判断返回结果是否吻合
+        compareHandler = POSIXCompare()
+
+        compareResult, compareReport = compareHandler.compare_text_files(
+            file1=fullLogFile,
+            file2=fullRefFile,
+            CompareIgnoreTailOrHeadBlank=True
+        )
+        if not compareResult:
+            for line in compareReport:
+                if line.startswith("-") or line.startswith("+"):
+                    print(line)
+        self.assertTrue(compareResult)
+
+    def test_sqllogmaskandfilter(self):
+        from ..testcli import TestCli
+
+        scriptFile = "testlogmaskandfilter.sql"
+
+        scriptBaseFile = os.path.splitext(scriptFile)[0]
+        fullScriptFile = os.path.abspath(os.path.join(os.path.dirname(__file__), "", scriptFile))
+        fullRefFile = os.path.abspath(os.path.join(os.path.dirname(__file__), "", scriptBaseFile + ".ref"))
+        fullLogFile = os.path.abspath(os.path.join(tempfile.gettempdir(), scriptBaseFile + ".log"))
+
+        # 运行测试程序，开启无头模式(不在控制台上显示任何内容),同时不打印Logo
+        testcli = TestCli(
+            logfilename=fullLogFile,
+            headlessMode=True,
+            script=fullScriptFile
+        )
+        retValue = testcli.run_cli()
+        self.assertEqual(0, retValue)
+
+        # 对文件进行比对，判断返回结果是否吻合
+        compareHandler = POSIXCompare()
+
+        compareResult, compareReport = compareHandler.compare_text_files(
+            file1=fullLogFile,
+            file2=fullRefFile,
+            CompareIgnoreTailOrHeadBlank=True
+        )
+        if not compareResult:
+            for line in compareReport:
+                if line.startswith("-") or line.startswith("+"):
+                    print(line)
+        self.assertTrue(compareResult)
+
+    def test_sqlautocommit(self):
+        from ..testcli import TestCli
+
+        scriptFile = "testautocommit.sql"
+
+        scriptBaseFile = os.path.splitext(scriptFile)[0]
+        fullScriptFile = os.path.abspath(os.path.join(os.path.dirname(__file__), "", scriptFile))
+        fullRefFile = os.path.abspath(os.path.join(os.path.dirname(__file__), "", scriptBaseFile + ".ref"))
+        fullLogFile = os.path.abspath(os.path.join(tempfile.gettempdir(), scriptBaseFile + ".log"))
+
+        # 运行测试程序，开启无头模式(不在控制台上显示任何内容),同时不打印Logo
         testcli = TestCli(
             logfilename=fullLogFile,
             headlessMode=True,
