@@ -12,7 +12,6 @@ import configparser
 import unicodedata
 import itertools
 import urllib3
-from multiprocessing import Lock
 from time import strftime, localtime
 
 from prompt_toolkit.history import FileHistory
@@ -25,11 +24,12 @@ from .hdfswrapper import HDFSWrapper
 from .testcliexception import TestCliException
 from .testclijobmanager import TestCliMeta
 from .testclijobmanager import JOBManager
-from .datawrapper import DataWrapper
 from .testoption import TestOptions
+from .globalvar import lastCommandResult
 from .__init__ import __version__
 from .sqlparse import SQLAnalyze
 from .apiparse import APIAnalyze
+from .commands.monitor import stopMonitorManager
 
 OFLAG_LOGFILE = 1
 OFLAG_LOGGER = 2
@@ -87,7 +87,6 @@ class TestCli(object):
         self.testOptions = TestOptions()                # 程序运行中各种参数
         self.HdfsHandler = HDFSWrapper()                # HDFS文件操作
         self.JobHandler = JOBManager()                  # 并发任务管理器
-        self.DataHandler = DataWrapper()                # 随机临时数处理
         self.MetaHandler = TestCliMeta()                # SQLCli元数据
         self.SpoolFileHandler = []                      # Spool文件句柄, 是一个数组，可能发生嵌套
         self.EchoFileHandler = None                     # 当前回显文件句柄
@@ -97,8 +96,8 @@ class TestCli(object):
         self.echofilename = None                        # 当前回显文件的文件名称
         self.Version = __version__                      # 当前程序版本
         self.xlogFile = None                            # xlog文件名
+        self.xlogFileFullPath = None                    # xlog文件名-绝对路径
         self.xlogFileHandle = None                      # xlog文件句柄
-        self.xlogFileLocker = None                      # 进程锁, 用来在输出perf文件的时候控制并发写文件
         self.breakWithError = breakWithError            # 是否在遇到错误的时候退出
         self.breakErrorCode = breakErrorCode            # 遇到错误的退出代码
         self.breakScenarioWithError = breakScenarioWithError  # 遇到命令行错误是否立刻退出当前Scenario的继续运行
@@ -203,8 +202,6 @@ class TestCli(object):
         self.cmdExecuteHandler.workerName = self.workerName
         self.cmdExecuteHandler.cmdMappingHandler = self.cmdMappingHandler
 
-        self.DataHandler.SQLOptions = self.testOptions
-
         # 设置WHENEVER_ERROR
         if breakWithError:
             self.testOptions.set("WHENEVER_ERROR", "EXIT " + str(self.breakErrorCode))
@@ -212,17 +209,26 @@ class TestCli(object):
             self.testOptions.set("WHENEVER_ERROR", "CONTINUE")
 
         # 加载程序的配置文件
-        # 搜先尝试读取TESTCLI_CONF中的信息，如果TESTCLI_CONF中没有信息，则从安装目录获取
-        self.appOptions = configparser.ConfigParser()
+        self.appOptions = None
         if "TESTCLI_CONF" in os.environ:
+            # 首先尝试读取TESTCLI_CONF中的信息
             confFilename = str(os.environ["TESTCLI_CONF"]).strip()
             if os.path.exists(confFilename):
+                self.appOptions = configparser.ConfigParser()
                 self.appOptions.read(confFilename)
             else:
                 raise TestCliException("Can not open config file [" + confFilename + "]")
-        else:
+        if self.appOptions is None and "TESTCLI_HOME" in os.environ:
+            # 其次尝试读取TESTCLI_HOME/conf/testcli.ini中的信息，如果有，以TESTCLI_HOME/conf/testcli.ini信息为准
+            confFilename = os.path.join(str(os.environ["TESTCLI_HOME"]).strip(), "conf", "testcli.ini")
+            if os.path.exists(confFilename):
+                self.appOptions = configparser.ConfigParser()
+                self.appOptions.read(confFilename)
+        if self.appOptions is None:
+            # 之前的读取都没有找到，以系统默认目录为准
             confFilename = os.path.join(os.path.dirname(__file__), "conf", "testcli.ini")
             if os.path.exists(confFilename):
+                self.appOptions = configparser.ConfigParser()
                 self.appOptions.read(confFilename)
             else:
                 raise TestCliException("Can not open config file [" + confFilename + "]")
@@ -239,6 +245,8 @@ class TestCli(object):
                 break
         if h2JarFile is None:
             raise TestCliException("Corruptted jlib directory. H2 driver file missed.")
+        if "driver" not in self.appOptions.sections():
+            self.appOptions.add_section("driver")
         self.appOptions.add_section("meta_driver")
         self.appOptions.set("meta_driver", "driver", "org.h2.Driver")
         self.appOptions.set("meta_driver", "jdbcurl",
@@ -265,11 +273,63 @@ class TestCli(object):
                 print('traceback.format_exc():\n%s' % traceback.format_exc())
             raise TestCliException("Can not open logfile for write [" + self.logfilename + "]")
 
+        # 如果要求打开扩展日志，则打开扩展日志
+        if self.xlogFile is not None:
+            # 创建文件，并写入文件头信息
+            if self.xlogOverwrite:
+                # 如果打开了覆盖模式，则删除之前的历史文件
+                if os.path.exists(self.xlogFile):
+                    os.remove(self.xlogFile)
+            self.xlogFileFullPath = os.path.abspath(self.xlogFile)
+            self.xlogFileHandle = sqlite3.connect(
+                database=self.xlogFile,
+                check_same_thread=False,
+            )
+            cursor = self.xlogFileHandle.cursor()
+            cursor.execute("CREATE TABLE IF NOT EXISTS TestCli_Xlog "
+                           "("
+                           "  Id              INTEGER PRIMARY KEY AUTOINCREMENT,"
+                           "  Script          TEXT,"
+                           "  Started         DATETIME,"
+                           "  Elapsed         NUMERIC,"
+                           "  RawCommand      TEXT,"
+                           "  CommandType     TEXT,"
+                           "  Command         TEXT,"
+                           "  CommandStatus   TEXT,"
+                           "  ErrorCode       TEXT,"
+                           "  WorkerName      TEXT,"
+                           "  SuiteName       TEXT,"
+                           "  CaseName        TEXT,"
+                           "  ScenarioId      TEXT,"
+                           "  ScenarioName    TEXT"
+                           ")"
+                           "")
+            cursor.execute("CREATE TABLE IF NOT EXISTS TestCli_PerfLog "
+                           "("
+                           "  Id              INTEGER PRIMARY KEY AUTOINCREMENT,"
+                           "  MonitorTime     DATETIME,"
+                           "  TaskId          NUMERIC,"
+                           "  TaskName        TEXT,"
+                           "  MonitorItem     TEXT,"
+                           "  MonitorValue    TEXT"
+                           ")")
+            cursor.close()
+
         # 加载已经被隐式包含的数据库驱动，文件放置在testcli\jlib下
         # 首先尝试TESTCLI_JLIBDIR下的内容，其次查看安装目录下的东西
+        jlibDirectory = None
         if "TESTCLI_JLIBDIR" in os.environ:
+            # 如果定义了TESTCLI_JLIBDIR，则查找TESTCLLI_JLIBDIR的位置
             jlibDirectory = str(os.environ["TESTCLI_JLIBDIR"])
-        else:
+            if not os.path.isdir(jlibDirectory):
+                raise TestCliException("Can not open jlib directory for read [" + jlibDirectory + "]")
+        if jlibDirectory is None and "TESTCLI_HOME" in os.environ:
+            # 如果定义了TESTCLI_HOME，则查找TESTCLI_HOME/jlib目录
+            jlibDirectory = str(os.path.join(os.environ["TESTCLI_HOME"], "jlib"))
+            if not os.path.isdir(jlibDirectory):
+                jlibDirectory = None
+        if jlibDirectory is None:
+            # 如果仍然找不到，则查找安装目录的jlib目录
             jlibDirectory = os.path.join(os.path.dirname(__file__), "jlib")
         if not os.path.isdir(jlibDirectory):
             raise TestCliException("Can not open jlib directory for read [" + jlibDirectory + "]")
@@ -305,7 +365,7 @@ class TestCli(object):
                         try:
                             m_jar_filename = self.appOptions.get(m_driversection, "filename")
                             if os.path.exists(os.path.join(jlibDirectory, m_jar_filename)):
-                                m_JarFullFileName.append(os.path.join(jlibDirectory, m_jar_filename))
+                                m_JarFullFileName.append(os.path.abspath(os.path.join(jlibDirectory, m_jar_filename)))
                                 if "TESTCLI_DEBUG" in os.environ:
                                     print("Load jar ..! [" +
                                           os.path.join(jlibDirectory, m_jar_filename) + "]")
@@ -342,33 +402,22 @@ class TestCli(object):
             self.testOptions.set("JOBMANAGER_METAURL", m_JobManagerURL)
 
         # 处理传递的映射文件, 首先加载参数的部分，如果环境变量里头有设置，则环境变量部分会叠加参数部分
-        self.testOptions.set("TESTREWRITE", "OFF")
         if self.commandMap is not None:
             # 如果传递的参数，有Mapping，以参数为准，先加载参数中的Mapping文件
             self.cmdMappingHandler.loadCommandMappings(self.commandScript, self.commandMap)
-            self.testOptions.set("TESTREWRITE", "ON")
         if "SQLCLI_COMMANDMAPPING" in os.environ:
             # 如果没有参数，则以环境变量中的信息为准
             if len(os.environ["SQLCLI_COMMANDMAPPING"].strip()) > 0:
                 self.cmdMappingHandler.loadCommandMappings(self.commandScript, os.environ["SQLCLI_COMMANDMAPPING"])
-                self.testOptions.set("TESTREWRITE", "ON")
         if "TESTCLI_COMMANDMAPPING" in os.environ:
             # 如果没有参数，则以环境变量中的信息为准
             if len(os.environ["TESTCLI_COMMANDMAPPING"].strip()) > 0:
                 self.cmdMappingHandler.loadCommandMappings(self.commandScript, os.environ["TESTCLI_COMMANDMAPPING"])
-                self.testOptions.set("TESTREWRITE", "ON")
 
         # 给Page做准备，PAGE显示的默认换页方式.
         if not os.environ.get("LESS"):
             os.environ["LESS"] = "-RXF"
 
-        # 如果参数要求不显示版本，则不再显示版本
-        if not self.nologo:
-            self.echo(
-                s="TestCli Release " + __version__,
-                Flags=OFLAG_LOGGER | OFLAG_CONSOLE | OFLAG_SPOOL | OFLAG_ECHO,
-            )
-
         # 处理初始化启动文件，如果需要的话，在处理的过程中不打印任何日志信息
         if len(self.profile) != 0:
             self.testOptions.set('OUTPUT_PREFIX', 'PROFILE')
@@ -397,94 +446,6 @@ class TestCli(object):
         if self.xlogFileHandle is not None:
             self.xlogFileHandle.close()
 
-    # 执行特殊的命令
-    @staticmethod
-    def execute_internal_command(cls, arg, **_):
-        # 处理并发JOB
-        match_obj = re.match(r"(\s+)?job(.*)$", arg, re.IGNORECASE | re.DOTALL)
-        if match_obj:
-            (title, result, headers, columnTypes, status) = cls.JobHandler.Process_Command(arg)
-            yield {
-                "title": title,
-                "rows": result,
-                "headers": headers,
-                "columnTypes": columnTypes,
-                "status": status
-            }
-            return
-
-        # 处理Transaction
-        match_obj = re.match(r"(\s+)?transaction(.*)$", arg, re.IGNORECASE | re.DOTALL)
-        if match_obj:
-            (title, result, headers, columnTypes, status) = cls.TransactionHandler.Process_Command(arg)
-            yield {
-                "title": title,
-                "rows": result,
-                "headers": headers,
-                "columnTypes": columnTypes,
-                "status": status
-            }
-            return
-
-        # 测试管理
-        match_obj = re.match(r"(\s+)?test(.*)$", arg, re.IGNORECASE | re.DOTALL)
-        if match_obj:
-            (title, result, headers, columnTypes, status) = cls.TestHandler.Process_SQLCommand(arg)
-            yield {
-                "title": title,
-                "rows": result,
-                "headers": headers,
-                "columnTypes": columnTypes,
-                "status": status
-            }
-            return
-
-        # 处理HDFS数据
-        match_obj = re.match(r"(\s+)?hdfs(.*)$", arg, re.IGNORECASE | re.DOTALL)
-        if match_obj:
-            if cls.cmdExecuteHandler.script is not None:
-                cls.HdfsHandler.HDFS_LCD(os.path.dirname(cls.cmdExecuteHandler.script))
-            (title, result, headers, columnTypes, status) = cls.HdfsHandler.Process_SQLCommand(arg)
-            yield {
-                "title": title,
-                "rows": result,
-                "headers": headers,
-                "columnTypes": columnTypes,
-                "status": status
-            }
-            return
-
-        # 处理随机数据文件
-        match_obj = re.match(r"(\s+)?data(.*)$", arg, re.IGNORECASE | re.DOTALL)
-        if match_obj:
-            for (title, result, headers, columnTypes, status) in \
-                    cls.DataHandler.Process_SQLCommand(arg):
-                yield {
-                    "title": title,
-                    "rows": result,
-                    "headers": headers,
-                    "columnTypes": columnTypes,
-                    "status": status
-                }
-            return
-
-        # 处理远程主机命令
-        match_obj = re.match(r"(\s+)?ssh(.*)$", arg, re.IGNORECASE | re.DOTALL)
-        if match_obj:
-            for (title, result, headers, columnTypes, status) in \
-                    cls.sshHandler.processCommand(arg):
-                yield {
-                    "title": title,
-                    "rows": result,
-                    "headers": headers,
-                    "columnTypes": columnTypes,
-                    "status": status
-                }
-            return
-
-        # 不认识的internal命令
-        raise TestCliException("Unknown internal Command [" + str(arg) + "]. Please double check.")
-
     # 逐条处理语句
     # 如果执行成功，返回true
     # 如果执行失败，返回false
@@ -676,8 +637,20 @@ class TestCli(object):
             self.echo(repr(e), err=True, fg="red")
             return False
 
+    # 返回语句的上一次执行结果
+    @staticmethod
+    def getLastCommandResult():
+        return lastCommandResult
+
     # 主程序
     def run_cli(self):
+        # 如果参数要求不显示版本，则不再显示版本
+        if not self.nologo:
+            self.echo(
+                s="TestCli Release " + __version__,
+                Flags=OFLAG_LOGGER | OFLAG_CONSOLE | OFLAG_SPOOL | OFLAG_ECHO,
+            )
+
         # 如果运行在脚本方式下，不再调用PromptSession
         # 运行在无终端的模式下，也不会调用PromptSession
         # 对于脚本程序，在执行脚本完成后就会自动退出
@@ -741,6 +714,9 @@ class TestCli(object):
         except (TestCliException, EOFError):
             pass
 
+        # 关闭监控进程
+        stopMonitorManager()
+
         # 退出进程, 如果要求不显示logo，则也不会显示Disconnected字样
         if self.exitValue == 0:
             if not self.nologo:
@@ -1115,50 +1091,17 @@ class TestCli(object):
         # SQL的前20个字母  SQLPrefix
         # 运行状态         SQLStatus
         # 错误日志         ErrorMessage
-        # 线程名称         thread_name
+        # 线程名称         processName
 
         # 如果没有打开性能日志记录文件，直接跳过
-        if self.xlogFile is None:
+        if self.xlogFileHandle is None:
             return
 
-        # 初始化文件加锁机制
-        if self.xlogFileLocker is None:
-            self.xlogFileLocker = Lock()
-
         # 多进程，多线程写入，考虑锁冲突
         try:
-            self.xlogFileLocker.acquire()
-            if self.xlogFileHandle is None:
-                # 创建文件，并写入文件头信息
-                if self.xlogOverwrite:
-                    # 如果打开了覆盖模式，则删除之前的历史文件
-                    if os.path.exists(self.xlogFile):
-                        os.remove(self.xlogFile)
-                self.xlogFileHandle = sqlite3.connect(self.xlogFile)
-                cursor = self.xlogFileHandle.cursor()
-                cursor.execute("CREATE TABLE IF NOT EXISTS TestCli_Xlog "
-                               "("
-                               "  Id              INTEGER PRIMARY KEY AUTOINCREMENT,"
-                               "  Script          TEXT,"
-                               "  Started         DATETIME,"
-                               "  Elapsed         NUMERIC,"
-                               "  RawCommand      TEXT,"
-                               "  CommandType     TEXT,"
-                               "  Command         TEXT,"
-                               "  CommandStatus   TEXT,"
-                               "  ErrorCode       TEXT,"
-                               "  WorkerName      TEXT,"
-                               "  SuiteName       TEXT,"
-                               "  CaseName        TEXT,"
-                               "  ScenarioId      TEXT,"
-                               "  ScenarioName    TEXT"
-                               ")"
-                               "")
-                cursor.close()
-
-            # 对于多线程运行，这里的thread_name格式为JOB_NAME#副本数-完成次数
-            # 对于单线程运行，这里的thread_name格式为固定的MAIN
-            threadName = str(commandResult["thread_name"])
+            # 对于多线程运行，这里的processName格式为JOB_NAME#副本数-完成次数
+            # 对于单线程运行，这里的processName格式为固定的MAIN
+            processName = str(commandResult["processName"])
 
             # 写入内容信息
             if self.executeScript is None:
@@ -1175,7 +1118,7 @@ class TestCli(object):
                 str(commandResult["command"]),
                 str(commandResult["commandStatus"]),
                 str(commandResult["errorCode"]),
-                str(threadName),
+                str(processName),
                 str(self.suitename),
                 str(self.casename),
                 str(commandResult["scenarioId"]),
@@ -1192,8 +1135,3 @@ class TestCli(object):
             self.xlogFileHandle.commit()
         except Exception as ex:
             print("Internal error:: xlog file [" + str(self.xlogFile) + "] write not complete. " + repr(ex))
-        finally:
-            if self.xlogFileHandle:
-                self.xlogFileHandle.close()
-                self.xlogFileHandle = None
-            self.xlogFileLocker.release()
